pub struct TestFixture { /* private fields */ }Implementations
Sourceimpl TestFixture
impl TestFixture
pub async fn new() -> Self
pub async fn new_with_device(device: DeviceHolder) -> Self
pub async fn new_unencrypted() -> Self
pub async fn open(device: DeviceHolder, options: TestFixtureOptions) -> Self
Sourcepub async fn close(self) -> DeviceHolder
pub async fn close(self) -> DeviceHolder
Closes the test fixture, shutting down the filesystem. Returns the device, which can be reused for another TestFixture.
Ensures that:
- The filesystem shuts down cleanly.
- fsck passes.
- There are no dangling references to the device or the volume.
pub fn root(&self) -> &DirectoryProxy
pub fn crypt(&self) -> Option<Arc<CryptBase>>
pub fn fs(&self) -> &Arc<FxFilesystem>
pub fn volume(&self) -> &FxVolumeAndRoot
pub fn volumes_directory(&self) -> &Arc<VolumesDirectory>
pub fn volume_out_dir(&self) -> &DirectoryProxy
pub fn memory_pressure_proxy(&self) -> &WatcherProxy